summaryrefslogtreecommitdiffstats
path: root/build.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:18:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:18:57 -0600
commit752274609034af8c68c46d19bed586ea6ae348b8 (patch)
treee8e76ca1acfa09d45f399a88cb3ada51992ae574 /build.py
parentd2b09f66d0c8c8c26ec613b96d7c248e78a5c52f (diff)
downloadpytqt-752274609034af8c68c46d19bed586ea6ae348b8.tar.gz
pytqt-752274609034af8c68c46d19bed586ea6ae348b8.zip
Fix retquire
Diffstat (limited to 'build.py')
-rw-r--r--build.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/build.py b/build.py
index 692fa50..c164c71 100644
--- a/build.py
+++ b/build.py
@@ -289,7 +289,7 @@ def generateFeatures(featfile):
sipconfig.inform("Generating the features file.")
# The features that a given TQt configuration may or may not support. Note
# that STYLE_WINDOWSXP retquires special handling.
flist = ["ACTION", "CLIPBOARD", "CODECS", "COLORDIALOG", "DATASTREAM",
"DIAL", "DNS", "DOM", "DRAGANDDROP", "ICONVIEW", "IMAGE_TEXT",
"INPUTDIALOG", "FILEDIALOG", "FONTDATABASE", "FONTDIALOG",
@@ -528,7 +528,7 @@ def main(argv):
# Early versions of TQt for the Mac didn't include everything. Rather than
# maintain these in the future we just mandate a later version.
if sys.platform == "darwin" and config.qt_version < 0x030100:
- sipconfig.error("PyTQt for MacOS/X retquires TQt v3.1.0 or later.\n")
+ sipconfig.error("PyTQt for MacOS/X requires TQt v3.1.0 or later.\n")
# Check the installation directory is valid and add it as a patch.
if not os.access(modDir,os.F_OK):
@@ -289,7 +289,7 @@ def generateFeatures(featfile):
sipconfig.inform("Generating the features file.")
# The features that a given TQt configuration may or may not support. Note
- # that STYLE_WINDOWSXP retquires special handling.
+ # that STYLE_WINDOWSXP requires special handling.
flist = ["ACTION", "CLIPBOARD", "CODECS", "COLORDIALOG", "DATASTREAM",
"DIAL", "DNS", "DOM", "DRAGANDDROP", "ICONVIEW", "IMAGE_TEXT",